==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/java/Projenrc.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Allows writing projenrc files in java.
 * <p>
 * This will install <code>org.projen/projen</code> as a Maven dependency and will add a
 * <code>synth</code> task which will compile &amp; execute <code>main()</code> from
 * <code>src/main/java/projenrc.java</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.828Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.Projenrc")
public class Projenrc extends io.github.cdklabs.projen.Component {

    protected Projenrc(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Projenrc(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.java.ProjenrcOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required"), options });
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required") });
    }

    /**
     * (experimental) The name of the java class that includes the projen entrypoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getClassName() {
        return software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.Projenrc}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.Projenrc> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         * @param pom This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            return new Builder(project, pom);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.Pom pom;
        private io.github.cdklabs.projen.java.ProjenrcOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            this.project = project;
            this.pom = pom;
        }

        /**
         * (experimental) The name of the Java class which contains the `main()` method for projen.
         * <p>
         * Default: "projenrc"
         * <p>
         * @return {@code this}
         * @param className The name of the Java class which contains the `main()` method for projen. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder className(final java.lang.String className) {
            this.options().className(className);
            return this;
        }

        /**
         * (experimental) The projen version to use.
         * <p>
         * Default: - current version
         * <p>
         * @return {@code this}
         * @param projenVersion The projen version to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenVersion(final java.lang.String projenVersion) {
            this.options().projenVersion(projenVersion);
            return this;
        }

        /**
         * (experimental) Defines projenrc under the test scope instead of the main scope, which is reserved to the app.
         * <p>
         * This means that projenrc will be under
         * <code>src/test/java/projenrc.java</code> and projen will be defined as a test
         * dependency. This enforces that application code does not take a dependency
         * on projen code.
         * <p>
         * If this is disabled, projenrc should be under
         * <code>src/main/java/projenrc.java</code>.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param testScope Defines projenrc under the test scope instead of the main scope, which is reserved to the app. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder testScope(final java.lang.Boolean testScope) {
            this.options().testScope(testScope);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.java.Projenrc}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.Projenrc build() {
            return new io.github.cdklabs.projen.java.Projenrc(
                this.project,
                this.pom,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.java.ProjenrcOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.java.ProjenrcOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/java/Projenrc.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Allows writing projenrc files in java.
 * <p>
 * This will install <code>org.projen/projen</code> as a Maven dependency and will add a
 * <code>synth</code> task which will compile &amp; execute <code>main()</code> from
 * <code>src/main/java/projenrc.java</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.494Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.Projenrc")
public class Projenrc extends io.github.cdklabs.projen.ProjenrcFile {

    protected Projenrc(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Projenrc(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.java.ProjenrcOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required"), options });
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required") });
    }

    /**
     * (experimental) The name of the java class that includes the projen entrypoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getClassName() {
        return software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The path of the projenrc file.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFilePath() {
        return software.amazon.jsii.Kernel.get(this, "filePath", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.Projenrc}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.Projenrc> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         * @param pom This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            return new Builder(project, pom);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.Pom pom;
        private io.github.cdklabs.projen.java.ProjenrcOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            this.project = project;
            this.pom = pom;
        }

        /**
         * (experimental) The name of the Java class which contains the <code>main()</code> method for projen.
         * <p>
         * Default: "projenrc"
         * <p>
         * @return {@code this}
         * @param className The name of the Java class which contains the <code>main()</code> method for projen. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder className(final java.lang.String className) {
            this.options().className(className);
            return this;
        }

        /**
         * (experimental) The projen version to use.
         * <p>
         * Default: - current version
         * <p>
         * @return {@code this}
         * @param projenVersion The projen version to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenVersion(final java.lang.String projenVersion) {
            this.options().projenVersion(projenVersion);
            return this;
        }

        /**
         * (experimental) Defines projenrc under the test scope instead of the main scope, which is reserved to the app.
         * <p>
         * This means that projenrc will be under
         * <code>src/test/java/projenrc.java</code> and projen will be defined as a test
         * dependency. This enforces that application code does not take a dependency
         * on projen code.
         * <p>
         * If this is disabled, projenrc should be under
         * <code>src/main/java/projenrc.java</code>.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param testScope Defines projenrc under the test scope instead of the main scope, which is reserved to the app. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder testScope(final java.lang.Boolean testScope) {
            this.options().testScope(testScope);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.java.Projenrc}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.Projenrc build() {
            return new io.github.cdklabs.projen.java.Projenrc(
                this.project,
                this.pom,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.java.ProjenrcOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.java.ProjenrcOptions.Builder();
            }
            return this.options;
        }
    }
}
